## Todoska

Todoska is a simple, fast, and powerful todo list manager.


## Installation

```python
pip install todoska
```


## Usage

```python
Figuring out dude ,
```


Usage :

- Add new task :

todoska add <task-name>

- Update a task :

todoska update <task-id> <task-name>

- Delete a task :

todoska delete <task-id>

- View All task :

todoska show


